@@ -388,3 +388,7 @@ IDirectFBGL *IDirectFBSurface::GetGL()
      return idirectfbgl;
 }
 
+void IDirectFBSurface::GetClip (DFBRegion *clip)
+{
+     DFBCHECK( iface->GetClip (iface, clip) );
+}
